@@ -322,7 +322,7 @@ if __name__ == '__main__':
 
 else:
     print(f'[{time.ctime()}][main/Info] now varbile "__name__"={__name__},run in web mode')
-    run('1.0.8')
+    run('1.3')
 
 
 
