@@ -1,5 +1,6 @@
 from bs4 import BeautifulSoup
 import os,sys
+import subprocess
 def install(moudle=None,index='https://pypi.tuna.tsinghua.edu.cn/simple'):
     pip_path=''
 
@@ -7,7 +8,9 @@ def install(moudle=None,index='https://pypi.tuna.tsinghua.edu.cn/simple'):
         pip_path += i + '\\'
     pip_path += 'Scripts\\pip.exe'
     command = f'{sys.executable} {pip_path} install {moudle} -i {index}'
-    return os_popen(command)
+    with open('install.bat','w') as f:
+        f.write('@echo off\n'+command)
+    subprocess.call('install.bat')
 def uninstall(moudle=None):
     pip_path = ''
 
@@ -15,13 +18,9 @@ def uninstall(moudle=None):
         pip_path += i + '\\'
     pip_path += 'Scripts\\pip.exe'
     command = f'{sys.executable} {pip_path} uninstall {moudle}'
-    return os_popen(command)
-def os_popen(strt):
-    try:
+    with open('uninstall.bat','w') as f:
+        f.write('@echo off\n'+command)
+    subprocess.call('uninstall.bat')
 
-        re = os.popen(strt).readlines()
-        return re
-    except BaseException as e:
-        print(e)
 if __name__ == '__main__':
     print(install('pip'))
\ No newline at end of file
